@@ -4,34 +4,30 @@
 #'
 #' @param object An object of class \code{svem_model}.
 #' @param newdata A data frame of new predictor values.
-#' @param debias Logical; default is \code{TRUE}.
+#' @param debias Logical; default is \code{FALSE}.
 #' @param se.fit Logical; if \code{TRUE}, returns standard errors (default is \code{FALSE}).
 #' @param ... Additional arguments.
 #' @importFrom stats terms reformulate na.pass
 #' @return Predictions or a list containing predictions and standard errors.
 #' @details
 #'
-#'A debiased fit is output (along with the standard fit). This is provided to allow the user to match the output of JMP. \code{https://www.jmp.com/support/help/en/18.1/?utm_source=help&utm_medium=redirect#page/jmp/overview-of-selfvalidated-ensemble-models.shtml}. The debiasing coefficients are always calculated by SVEMnet(), and the predict() function determines whether the raw or debiased predictions are returned via the \code{debias} argument.
+#'A debiased fit is available (along with the standard fit). This is provided to allow the user to match the output of JMP.\\ https://www.jmp.com/support/help/en/18.1/?utm_source=help&utm_medium=redirect#page/jmp/overview-of-selfvalidated-ensemble-models.shtml. The debiasing coefficients are always calculated by SVEMnet(), and the predict() function determines whether the raw or debiased predictions are returned via the \code{debias} argument. Default is \code{FALSE} based on performance on unpublished simulation studies.
 #'
 #' @section Acknowledgments:
 #' Development of this package was assisted by GPT o1-preview, which helped in constructing the structure of some of the code and the roxygen documentation. The code for the significance test is taken from the supplementary material of Karl (2024) (it was handwritten by that author).
 #'
 #' @export
-predict.svem_model <- function(object, newdata, debias = TRUE, se.fit = FALSE, ...) {
+predict.svem_model <- function(object, newdata, debias = FALSE, se.fit = FALSE, ...) {
   if (!is.data.frame(newdata)) {
     stop("newdata must be a data frame.")
   }
 
-  # Extract RHS-only formula from the stored formula
-  terms_obj <- terms(object$formula)
-  rhs_formula <- reformulate(attr(terms_obj, "term.labels"))
-
-  # Set the environment of rhs_formula to baseenv() to avoid conflicts
-  environment(rhs_formula) <- baseenv()
+  # Use the stored terms object but remove the response variable
+  terms_obj <- delete.response(object$terms)
 
   # Create model frame and model matrix for newdata
-  mf <- model.frame(rhs_formula, data = newdata, na.action = na.pass)
-  X_new <- model.matrix(rhs_formula, data = mf)
+  mf <- model.frame(terms_obj, data = newdata, na.action = na.pass)
+  X_new <- model.matrix(terms_obj, data = mf)
 
   # Remove intercept column
   intercept_col <- which(colnames(X_new) == "(Intercept)")
@@ -59,17 +55,14 @@ predict.svem_model <- function(object, newdata, debias = TRUE, se.fit = FALSE, .
   # Compute mean predictions
   predictions_mean <- rowMeans(predictions_matrix, na.rm = FALSE)
 
-  # Determine debiasing based on 'debias' argument
-
+  # Apply debiasing if requested
   if (debias && !is.null(object$debias_fit)) {
     debias_coef <- coef(object$debias_fit)
     if (length(debias_coef) == 2) {
-      # debias_fit has intercept and slope
       a <- debias_coef[1]
       b <- debias_coef[2]
       predictions_mean <- a + b * predictions_mean
     } else {
-      # debias_fit is intercept-only
       predictions_mean <- rep(debias_coef[1], m)
     }
   }
